# Topsis Package by Gagandeep Singh 101803390

<h3>This package gives the function save_topsis(input,weights,target,output) which takes four parameters:</h3>
   
<ul> 
    <li> input : is the location of input file </li>
    <li> weight : this takes the input value of every parameter weights "0.1,0.2,0.3,0.4" </li>
    <li> target : this takes the +ve and -ve as input to take whether to maximize or minimize a parameter </li>
    <li> output : is the location of the csv file where u want to save it </li>
</ul>  

[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
